@@ -65,12 +65,11 @@ class Auth(object):
 
     def __init__(self, app=None, provider=None):
         self.principal = Principal(use_sessions=False)
-        self.provider = provider
         self.require = PermissionFactory()
 
         self.app = app
-        if self.app: # pragma: no cover
-            self.init_app(app, self.provider)
+        if self.app:  # pragma: no cover
+            self.init_app(app, provider)
 
     def init_app(self, app, provider=None):
         app.config.setdefault('CARAFE_AUTH_SESSION_ID_KEY', 'user_id')
@@ -103,6 +102,10 @@ class Auth(object):
     def user_id(self):
         return session.get(self.session_id_key)
 
+    @property
+    def provider(self):
+        return current_app.extensions[self._extension_name]['provider']
+
     def session_identity_loader(self):
         '''Fetch user id from session using config's auth id key'''
         if self.session_id_key in session:
@@ -117,10 +120,8 @@ class Auth(object):
         # whatever is returned is used for our identity
         # potentially, provider may return a different user than original identity
         # (e.g. app provides way for admin users to access site using a different user account)
-        provider = current_app.extensions[self._extension_name]['provider']
-
-        if provider:
-            ident = provider.identify(identity)
+        if self.provider:
+            ident = self.provider.identify(identity)
         else:
             ident = {self.identity_id_key: None}
 
